@@ -12,4 +12,4 @@ from .Relation import *
 from .Properties import *
 from .Color import *
 from .Syntax import *
-# from .Search import *
\ No newline at end of file
+from .Search import *
\ No newline at end of file
